/**
 * useDebounce
 * Creates a stable-identity debounced function.
 * The wrapped function has two methods attached:
 *    `.cancel()` to cancel any pending invocations
 *    `.flush()` to immediately execute an pending invocations
 * The wrapped function returns a Promise that will be resolved with the return value of the debounced function once its execution is completed.
 * @param fn the function to be debounced
 * @param ms duration in milliseconds since the last invocation that must elapse before the next invocation is executed
 */
export default function useDebounce<T extends (...args: any) => any>(fn: T, ms: number): ((this: ThisParameterType<T>, ..._args: Parameters<T>) => Promise<ReturnType<T>>) & {
    cancel: () => boolean;
    flush: () => void;
};
