/**
 * There are situations where a React component needs to know the hover state
 * of a child/sibling component, most commonly for applying complementary hover styles
 *
 * Usage Example:
 *
 * const Foo = () => {
 *  const { isHovered, ref } = useHover<HTMLButtonElement>();
 *  return (
 *    <>
 *      <button ref={ref}>Click me</button>
 *      <div>{isHovered ? 'button hovered' : 'button not hovered'}</div>
 *    </>
 *  )
 * }
 */
import * as React from 'react';
interface IUseHoverReturnType<T extends HTMLElement> {
    isHovered: boolean;
    ref: React.MutableRefObject<T | null>;
}
declare const _default: <T extends HTMLElement>() => IUseHoverReturnType<T>;
export default _default;
