/**
 * There are situations where a React component needs to know the hover state
 * of a child/sibling component, most commonly for applying complementary hover styles
 *
 * Usage Example:
 *
 * const Foo = () => {
 *  const { isHovered, ref } = useHover<HTMLButtonElement>();
 *  return (
 *    <>
 *      <button ref={ref}>Click me</button>
 *      <div>{isHovered ? 'button hovered' : 'button not hovered'}</div>
 *    </>
 *  )
 * }
 */
import * as React from 'react';
export default (() => {
  var [isHovered, setIsHovered] = React.useState(false);
  var ref = React.useRef(null);

  var onMouseOverHandler = () => {
    setIsHovered(true);
  };

  var onMouseOutHandler = () => {
    setIsHovered(false);
  };

  React.useEffect(() => {
    var element = ref === null || ref === void 0 ? void 0 : ref.current;

    if (ref && element) {
      element.addEventListener('mouseenter', onMouseOverHandler);
      element.addEventListener('mouseleave', onMouseOutHandler);
      return () => {
        element.removeEventListener('mouseenter', onMouseOverHandler);
        element.removeEventListener('mouseleave', onMouseOutHandler);
      };
    }
  });
  return {
    isHovered,
    ref
  };
});