import { useState, useEffect } from 'react';
import debounce from 'lodash/debounce';

export default function useRenderOnResize() {
  const [_, setSize] = useState(window.innerWidth);
  useEffect(() => {
    const handleResize = debounce(() => setSize(window.innerWidth), 250);
    window.addEventListener('resize', handleResize, {
      capture: true
    });
    return () =>
      window.removeEventListener('resize', handleResize, {
        capture: true
      });
  }, []);
}
